library(scales)
library(lme4)
library(lmerTest)

# use the data from the 'Suppl Data.xls' file
# (sheet 'OS.surv' for larval survival, 'Dev.time' for development duration and 'Emerge.wt' for body mass at emergence)
## Larval survival ----
dat<-read.delim('clipboard'); head(dat)
m1<-glm(cbind(dat$num_eggs, dat$num_nohatch)~factor(dat$Day), family=binomial(link = "logit"))
summary(m1)


## Development duration ----
dat<-read.delim('clipboard'); head(dat)
m1<-lmer(dat$Development_time~factor(dat$Day) + (1|dat$Mother))
summary(m1)
#           Estimate Std. Error      df t value Pr(>|t|)    
# (Intercept)        32.3857     0.3044 37.1544 106.387   <2e-16 ***
# factor(datm$Day)2   0.3952     0.4289 36.8349   0.922    0.363

# Figure A)
plot(dat$Development_time~factor(dat$Day),
     xlab='Day', ylab='Development duration [days]',
     col=0, border=0, las=1, axes = F, ylim=c(30,40))
points(jitter((dat$Day), 0.4), dat$Development_time, pch=16, col='violet', cex=0.6)
axis(1, at=c(1,2)); axis(2, at=seq(30,40,2), las=1)
points(1,31.99, pch=21, cex=2, bg=6, col=0, lwd=1.5)
points(2,31.99+0.4, pch=21, cex=2, bg=6, col=0)
lines(c(1,1), c(31.99-1.96*0.6797,31.99+1.96*0.6797), lwd=2, col=6)
lines(c(2,2), c(31.99+0.4+1.96*0.4289, 31.99+0.4-1.96*0.4289), lwd=2, col=6)
text(0.75, 40-10/10, 'A)', cex=2)

## Body mass at emergence ----
dat<-read.delim('clipboard'); head(dat)
m1<-lmer(dat$Emerge_Weight~factor(dat$Day) + dat$Sex + (1|dat$Mother))
summary(m1)
#          Estimate Std. Error        df t value Pr(>|t|)    
# (Intercept)        5.87050    0.09116  54.42554  64.395   <2e-16 ***
# factor(dat$Day)2  -0.09911    0.11989  35.88504  -0.827    0.414    
# dat$SexM          -2.25965    0.09415 106.74235 -24.001   <2e-16 ***


# Figure B)
datm<-subset(dat, Sex=='M')
plot(datm$Emerge_Weight~factor(datm$Day),
     xlab='Day', ylab='Body mass at emergence [mg]',
     col=0, border=0, las=1, axes = F, ylim=c(2,8))
points(jitter((datm$Day-0.1), 0.4), datm$Emerge_Weight, pch=16, col=4, cex=0.6)
datf<-subset(dat, Sex=='F')
points(jitter((datf$Day+0.1), 0.4), datf$Emerge_Weight, pch=16, col=2, cex=0.6)
axis(1, at=c(1,2)); axis(2, at=seq(2,8,1), las=1)
points(1.1,5.97, pch=21, cex=2, bg='red', col=0, lwd=1.5)
points(2.1,5.97-0.1, pch=21, cex=2, bg='red', col=0)
lines(c(1.1,1.1), c(5.97+1.96*0.18390,5.97-1.96*0.18390), lwd=2, col='red')
lines(c(2.1,2.1), c(5.97-0.1+1.96*0.11989, 5.97-0.1-1.96*0.11989), lwd=2, col='red')
points(0.9,5.97-2.26, pch=21, cex=2, bg='blue', col=0, lwd=1.5)
points(1.9,5.97-2.26-0.1, pch=21, cex=2, bg='blue', col=0)
lines(c(0.9,0.9), c(5.97-2.26+1.96*0.09415,5.97-2.26-1.96*0.09415), lwd=2, col='blue')
lines(c(1.9,1.9), c(5.97-2.26-0.1+1.96*0.11989, 5.97-2.26-0.1-1.96*0.11989), lwd=2, col='blue')
legend('top', c('females', 'males'), pch=16, col=c('red','blue'), bty='n', title='Offspring')
text(0.75, 8-6/10, 'B)', cex=2)
